<?php

/* * ********************************************************************
 *  Provisioning Module for NodePing. Custom developed.
 * *
 *
 *  CREATED BY MODULESGARDEN       ->       http://modulesgarden.com
 *  CONTACT                        ->       contact@modulesgarden.com
 *
 *
 * This software is furnished under a license and may be used and copied
 * only  in  accordance  with  the  terms  of such  license and with the
 * inclusion of the above copyright notice.  This software  or any other
 * copies thereof may not be provided or otherwise made available to any
 * other person.  No title to and  ownership of the  software is  hereby
 * transferred.
 *
 *
 * ******************************************************************** */

/**
 * @author Bogusław Kotarski <boguslaw.ko@modulesgarden.com>
 */
class NodePing {

    private $curl;
    private $apiURL;
    private $token;

    public function __construct($token) {
        $this->curl   = new NodePingCurl();
        $this->apiURL = 'https://api.nodeping.com/api/1/';
        $this->token  = $token;

    }

    public function createSubAccount($values) {
        $URL = $this->apiURL . 'accounts';
        $this->addTokenToArray($values);
        return $this->curl->post($URL, $values);

    }

    public function deleteSubAccount($customerID) {
        $URL    = $this->apiURL . 'accounts';
        $values = array('customerid' => $customerID);
        $this->addTokenToArray($values);
        return $this->curl->delete($URL, $values);

    }

    public function getSubAccountInfo($customerID) {
        $URL = $this->apiURL . 'accounts/' . $customerID;
        $this->addTokenToArray($values);
        return $this->curl->get($URL, $values);

    }

    public function suspendSubAccount($customerID) {
        $URL    = $this->apiURL . 'accounts';
        $values = array(
            'customerid' => $customerID,
            'status'     => 'Suspend',
        );
        $this->addTokenToArray($values);
        return $this->curl->put($URL, $values);

    }

    public function activateSubAccount($customerID) {
        $URL    = $this->apiURL . 'accounts';
        $values = array(
            'customerid' => $customerID,
            'status'     => 'Active',
        );
        $this->addTokenToArray($values);
        return $this->curl->put($URL, $values);

    }

    public function updateSubAccount($customerID, $values) {
        $URL                  = $this->apiURL . 'accounts';
        $values['customerid'] = $customerID;
        $this->addTokenToArray($values);
        return $this->curl->put($URL, $values);

    }

    public function getSubAccountContact($customerID, $contactID) {
        $URL                  = $this->apiURL . 'contacts';
        $values['customerid'] = $customerID;
        $values['id']         = $contactID;
        $this->addTokenToArray($values);
        return $this->curl->get($URL, $values);

    }

    public function getSubAccountContacts($customerID) {
        $URL                  = $this->apiURL . 'contacts';
        $values['customerid'] = $customerID;
        $this->addTokenToArray($values);
        return $this->curl->get($URL, $values);

    }

    public function updateSubAccountContact($customerID, $contactID, $name, $custrole, $oldAddress, $newAddress) {
        $URL                    = $this->apiURL . 'contacts';
        $values['customerid']   = $customerID;
        $values['id']           = $contactID;
        $values['name']         = $name;
        $values['custrole']     = $custrole;
        $values['addresses']    = $oldAddress;
        $values['newaddresses'] = $newAddress;
        $this->addTokenToArray($values);
        return $this->curl->put($URL, $values);

    }

    public function addSubAccountContact($customerID, $name, $custrole, $newAddress) {
        $URL                    = $this->apiURL . 'contacts';
        $values['customerid']   = $customerID;
        $values['name']         = $name;
        $values['custrole']     = $custrole;
        $values['newaddresses'] = $newAddress;
        $this->addTokenToArray($values);
        return $this->curl->post($URL, $values);

    }

    public function deleteSubAccountContact($customerID, $contactID) {
        $URL                  = $this->apiURL . 'contacts/' . $contactID;
        $values['customerid'] = $customerID;
        $this->addTokenToArray($values);
        return $this->curl->delete($URL, $values);

    }

    public function getSubAccountGroups($customerID) {
        $URL                  = $this->apiURL . 'contactgroups';
        $values['customerid'] = $customerID;
        $this->addTokenToArray($values);
        return $this->curl->get($URL, $values);

    }

    public function getSubAccountGroup($customerID, $groupID) {
        $URL                  = $this->apiURL . 'contactgroups';
        $values['customerid'] = $customerID;
        $values['id']         = $groupID;
        $this->addTokenToArray($values);
        return $this->curl->get($URL, $values);

    }

    public function deleteSubAccountGroup($customerID, $groupID) {
        $URL                  = $this->apiURL . 'contactgroups/' . $groupID;
        $values['customerid'] = $customerID;
        $this->addTokenToArray($values);
        return $this->curl->delete($URL, $values);

    }

    public function updateSubAccountGroup($customerID, $contactID, $name, $members) {
        $URL                  = $this->apiURL . 'contactgroups';
        $values['customerid'] = $customerID;
        $values['id']         = $contactID;
        $values['name']       = $name;
        $values['members']    = $members;
        $this->addTokenToArray($values);
        return $this->curl->put($URL, $values);

    }

    public function addSubAccountGroup($customerID, $name, $members) {
        $URL                  = $this->apiURL . 'contactgroups';
        $values['customerid'] = $customerID;
        $values['name']       = $name;
        $values['members']    = $members;
        $this->addTokenToArray($values);
        return $this->curl->post($URL, $values);

    }

    public function getSubAccountChecks($customerID) {
        $URL                  = $this->apiURL . 'checks';
        $values['customerid'] = $customerID;
        $this->addTokenToArray($values);
        return $this->curl->get($URL, $values);

    }

    public function getSubAccountCheck($customerID, $checkID) {
        $URL                  = $this->apiURL . 'checks';
        $values['customerid'] = $customerID;
        $values['id']         = $checkID;
        $this->addTokenToArray($values);
        return $this->curl->get($URL, $values);

    }

    public function updateSubAccountCheck($customerID, $checkID, $values) {
        $URL                  = $this->apiURL . 'checks';
        $values['customerid'] = $customerID;
        $values['id']         = $checkID;
        $this->addTokenToArray($values);
        return $this->curl->put($URL, $values);

    }

    public function addSubAccountCheck($customerID, $values) {
        $URL                  = $this->apiURL . 'checks';
        $values['customerid'] = $customerID;
        $this->addTokenToArray($values);
        return $this->curl->post($URL, $values);

    }

    public function deleteSubAccountCheck($customerID, $checkID) {
        $URL                  = $this->apiURL . 'checks/' . $checkID;
        $values['customerid'] = $customerID;
        $this->addTokenToArray($values);
        return $this->curl->delete($URL, $values);

    }

    public function getSubAccountCheckNotify($customerID, $checkID) {
        $URL                  = $this->apiURL . 'notifications';
        $values['customerid'] = $customerID;
        $values['id']         = $checkID;
        $this->addTokenToArray($values);
        return $this->curl->get($URL, $values);

    }

    public function getSubAccountCheckResult($customerID, $checkID, $span, $limit = 43200) {
        $URL                  = $this->apiURL . 'results';
        $values['customerid'] = $customerID;
        $values['id']         = $checkID;
        $values['clean']      = 'true';
        //$values['span']       = $span;
        $values['limit']      = $limit;
        $this->addTokenToArray($values);
        return $this->curl->get($URL, $values);

    }

    private function addTokenToArray(&$values) {
        $values['token'] = $this->token;

    }

    public function getErrorText() {
        return $this->curl->getErrorText();

    }

    public function getChecks() {
        $URL                  = $this->apiURL . 'checks';
        $values = [];
        $this->addTokenToArray($values);
        return $this->curl->get($URL, $values);

    }


}
